#!/bin/bash 
cd $(dirname "$BASH_SOURCE")/..
source config.cfg
BATCHPATH=$(cd $(dirname "$BASH_SOURCE")/../software; pwd)

mkdir -p $TEMPPATH
mkdir -p $DESTPATH

#VIDEO DEFINITIONS
video1080pformat="137"; #Dash 1080p, no audio
video720pformat="22"; #Best 720p, with 192k audio
audio256format="141"; #256k audio

#FUNCTIONS
function getfilename() { #function to get filename of YouTube video
	if [ "$3" -eq "0" ]; then #don't use manifest
		$BATCHPATH/youtube-dl $1 --restrict-filenames --get-filename -f $2 -o "%(title)s (%(uploader)s) %(format)s.%(ext)s"
	else #use manifest
		$BATCHPATH/youtube-dl $1 --restrict-filenames --youtube-include-dash-manifest --get-filename -f $2 -o "%(title)s (%(uploader)s) %(format)s.%(ext)s"
	fi
}

function downloadfile() { #function to download YouTube video
	if [ "$3" -eq "0" ]; then #don't use manifest
		$BATCHPATH/youtube-dl $1 --restrict-filenames -f $2 -o "$TEMPPATH/%(title)s (%(uploader)s) %(format)s.%(ext)s"
	else #use manifest
		$BATCHPATH/youtube-dl $1 --restrict-filenames --youtube-include-dash-manifest -f $2 -o "$TEMPPATH/%(title)s (%(uploader)s) %(format)s.%(ext)s"
	fi
}

#START

videofilename=$(getfilename $1 $video1080pformat 0) #set videofilename to 1080p DASH video's filename

if [ -n "$videofilename" ]; then #if 1080p DASH exists, download 1080p
	videofilename=${videofilename%.*} #remove extension from video filename
	videofilesize="1080p"
	downloadfile $1 $video1080pformat 0 #download 1080p-DASH
else #check if 720p exists
	echo ""
	echo "1080p video not found! Trying 720p..."
	
	videofilename=$(getfilename $1 $video720pformat 0) #set videofilename to 720p video
	videofilesize="720p"
fi

if [ -n "$videofilename" ]; then #if 1080p DASH or 720p exists, videofilename would have been defined
	videofilename=${videofilename%.*} #remove extension from video filename
	audiofilename=$(getfilename $1 $audio256format 1) #set audiofilename
	if [ -n "$audiofilename" ]; then #If 256k audio exists, download audio
	    downloadfile $1 $audio256format 1
		audioquality="256k"
	fi
	
	if [[ -z "$audiofilename" || "$videofilesize" == "720p" ]];then #if 256k audio or 1080p video does not exist, need to download the 720p for the 192k audio
		downloadfile $1 $video720pformat 0 #download the 720p video

		if [ -z "$audiofilename" ]; then #if 256k audio does not exist, need to define the 192k audio
			audiofilename=$(getfilename $1 $video720pformat 0)
			audioquality="192k"
		fi
	fi
	
	if [[ "$audioquality" == "192k" && "$videofilesize" == "720p" ]];then #720p video will always have 192k audio
		mv -i "$TEMPPATH/$videofilename.mp4" "$DESTPATH/$videofilename nochange.mp4"
	else #mutiplex the streams of the 2 files
		$BATCHPATH/ffmpeg -i "$TEMPPATH/$videofilename.mp4" -i "$TEMPPATH/$audiofilename" -c copy -map 0:v -map 1:a "$DESTPATH/$videofilename + $audioquality audio.mp4"
		rm "$TEMPPATH/$videofilename.mp4"
		rm "$TEMPPATH/$audiofilename"
	fi
else
	echo ""
	echo "HD not found!"
fi

osascript -e 'tell application "Terminal" to quit'
exit
